ExecResult

Enum ExecResult 

pub enum ExecResult<V, I> {
    Finished {
        instance: V,
        gas_left: i64,
    },
    Syscall {
        execution: I,
        gas_left: i64,
        syscall_symbol: SyscallSymbol,
        a0: u64,
        a1: u64,
        a2: u64,
        a3: u64,
        a4: u64,
        a5: u64,
    },
    Error {
        instance: V,
        error: ExecError,
    },
}
The result of running a virtualization instance.

V is the idle Instance type (returned on completion or error), I is the Execution type (returned when a syscall is encountered).

Variants



Finished

Execution finished normally. Returns the idle instance for potential reuse.

Fields

instance: V

The idle instance, ready to be prepared for another call.

gas_left: i64

How much gas is remaining after the execution.



Syscall

A syscall was encountered. The caller should handle the syscall and then call Execution::run again to continue execution.

Fields

execution: I

The running execution, with memory access available for syscall handling.

gas_left: i64

How much gas is remaining at the point of the syscall.

syscall_symbol: SyscallSymbol

The symbol identifying the syscall.

a0: u64

Register arguments a0-a5.

a1: u64
a2: u64
a3: u64
a4: u64
a5: u64


Error

An error occurred during execution. Returns the idle instance.

Fields

instance: V

The idle instance, returned for potential reuse or cleanup.

error: ExecError

The error that occurred.