#[repr(i32)]pub enum ModuleError {
InvalidImage = -1,
NotCached = -2,
NotFound = -3,
}Expand description
Errors that can be emitted when compiling a program into a module.
Variants
InvalidImage = -1
The supplied code was invalid.
NotCached = -2
No module with the given identifier has been compiled yet.
NotFound = -3
No code was found at the supplied storage key.