VirtManagerExt

Struct VirtManagerExt 

pub struct VirtManagerExt(pub Box<dyn VirtManagerBackend>);
Extension wrapping a VirtManagerBackend so it can be accessed through the externalities by the virtualization host functions.

Tuple Fields

0: Box<dyn VirtManagerBackend>

Implementations

Source

impl VirtManagerExt

pub fn type_id() -> TypeId

Returns the TypeId of this extension.

Source

impl VirtManagerExt

pub fn new<B: VirtManagerBackend>(backend: B) -> Self

Wrap the given backend so it can be registered as an externalities extension.