#[repr(u8)]pub enum ExecError {
InvalidInstance = 1,
InvalidImage = 2,
OutOfGas = 3,
Trap = 4,
}Expand description
Errors that can be emitted when executing a new virtualization instance.
Variants
InvalidInstance = 1
The supplied instance_id was invalid or the instance was destroyed.
This error will also be returned if a recursive call into the same instance is attempted.
InvalidImage = 2
The supplied code was invalid. Most likely caused by invalid entry points.
OutOfGas = 3
The execution ran out of gas before it could finish.
Trap = 4
The execution trapped before it could finish.
This can be caused by executing an unimp instruction.