pub enum ExecResult<V, I> {
Finished {
instance: V,
gas_left: i64,
},
Syscall {
execution: I,
gas_left: i64,
syscall_symbol: SyscallSymbol,
a0: u64,
a1: u64,
a2: u64,
a3: u64,
a4: u64,
a5: u64,
},
Error {
instance: V,
error: ExecError,
},
}Expand description
Variants
Finished
Execution finished normally. Returns the idle instance for potential reuse.
Fields

instance: VThe idle instance, ready to be prepared for another call.
Syscall
A syscall was encountered. The caller should handle the syscall and then
call Execution::run again to continue execution.
Fields

execution: IThe running execution, with memory access available for syscall handling.

syscall_symbol: SyscallSymbolThe symbol identifying the syscall.
Error
An error occurred during execution. Returns the idle instance.